----------------------------------------------------------------------
--
-- Lookups.lua - TabardMaster's lookup tables
--
-- See individual sections for each table's functionality.
--
----------------------------------------------------------------------


----------------------------------------------------------------------
--
-- tm_reputationXRef - TabardMaster's reputation lookup table
--
-- Used to convert a faction ID to it's tabard, plus hold a localized 
-- faction name, group type ID, current and previous reputation ranks, 
-- total accrued reputation with the faction, and current and maximum
-- reputation values for current reputation rank.  group entry is
-- currently unused and may be removed later.
--
-- Table is initialized with limited data for just the factions that 
-- can be championed with tabards and will be populated later with 
-- data for all factions.
--
-- 'Guild' tabard IDs are 69210, 69209, 5976
-- 'Faction' (allegiance) tabards are anything NOT D80 or D85.
--
----------------------------------------------------------------------
tm_reputationXRef = {
	['1168'] = {tabard = 'guild', group = 'guild'},								-- Guild

	['47'] 	 = {tabard = 45577, group = 'city'},								-- Ironforge 
	['54'] 	 = {tabard = 45578, group = 'city'},								-- Gnomeregan 
	['68'] 	 = {tabard = 45583, group = 'city'},								-- Undercity 
	['69'] 	 = {tabard = 45579, group = 'city'},								-- Darnassus 
	['72'] 	 = {tabard = 45574, group = 'city'},								-- Stormwind 
	['76']	 = {tabard = 45581, group = 'city'},								-- Orgrimmar 
	['81'] 	 = {tabard = 45584, group = 'city'},								-- Thunder Bluff 
	['530']  = {tabard = 45582, group = 'city'},								-- Darkspear Trolls 
	['911']  = {tabard = 45585, group = 'city'},								-- Silvermoon City 
	['930']	 = {tabard = 45580, group = 'city'},								-- Exodar 
	['1133'] = {tabard = 64884, group = 'city'},								-- Bilgewater Cartel 
	['1134'] = {tabard = 64882, group = 'city'},								-- Gilneas 
	['1352'] = {tabard = 83080, group = 'city'},								-- Huojin Pandaren 
	['1353'] = {tabard = 83079, group = 'city'},								-- Tushui Pandaren 

	['1037'] = {tabard = 'faction', group = 'faction'},							-- Alliance Vanguard (Header)
	['1052'] = {tabard = 'faction', group = 'faction'},							-- Horde Expedition (Header)
	['1090'] = {tabard = 43157, group = 'D80'},									-- Kirin Tor 
	['1091'] = {tabard = 43156, group = 'D80'},									-- The Wyrmrest Accord 
	['1098'] = {tabard = 43155, group = 'D80'},									-- Knights of the Ebon Blade 
	['1106'] = {tabard = 43154, group = 'D80'},									-- Argent Crusade 

	['1135'] = {tabard = 65905, group = 'D85'},									-- The Earthen Ring 
	['1158'] = {tabard = 65906, group = 'D85'},									-- Guardians of Hyjal 
	['1171'] = {tabard = 65907, group = 'D85'},									-- Therazane 
	['1172'] = {tabard = 65909, group = 'D85'},									-- Dragonmaw Clan 
	['1173'] = {tabard = 65904, group = 'D85'},									-- Ramkahen 
	['1174'] = {tabard = 65908, group = 'D85'},									-- Wildhammer Clan 
}


----------------------------------------------------------------------
--
-- tm_factionXFer - Tabard to factionId lookup table for tabards that 
--	champion a faction
--
-- (Essentially the reverse of above; table will be used for speed)
--
----------------------------------------------------------------------
tm_tabardXRef = {}
for factionId, data in pairs(tm_reputationXRef) do
	if type(data.tabard) == 'number' then
		tm_tabardXRef[tostring(data.tabard)] = tonumber(factionId)
	end
end
-- add the factionIds for guild tabards 
tm_tabardXRef['5976']	= 1168
tm_tabardXRef['69209']	= 1168
tm_tabardXRef['69210']	= 1168


----------------------------------------------------------------------
-- 
-- tm_raidFaction - Instance (raid) to faction converter
--
-- Used to show reputation bar for a raid faction; indexes are 
--	raid mapIds.
--
----------------------------------------------------------------------
tm_raidFaction = {
	["696"] = "749",			-- Molten Core grants Hydraxian Waterlords reputation
	["717"] = "609 910",		-- Ruins of Ahn'Qiraj grants Cenarian Circle & Brood of Nozdormu reputation
	["772"] = "609 910",		-- Ahn'Qiraj: The Fallen Kingdom (AKA Temple) grants Cenarian Circle & Brood of Nozdormu reputation
	["799"] = "967",			-- Karazhan grants The Violet Eye reputation
	["775"] = "990",			-- Hyjal Summit grants The Scale of the Sands reputation
	["796"] = "1012",			-- The Black Temple grants Ashtongue Deathsworn reputation
	["604"] = "1156", 			-- Icecrown Citadel grants The Ashen Verdict reputation
	["752"] = "1177", 			-- Baradin Hold grants Baradin's Wardens reputation
	["800"] = "1204", 			-- Firelands grants Avengers of Hyjal reputation
	["953"] = "1492", 			-- Siege of Orgrimmar shows Emperor Shaohao reputation 
} 


----------------------------------------------------------------------
--
-- tm_tabardGroup - TabardMaster's default tabard categories
--
-- these are the itemIDs of all known tabards, grouped into 
-- categories.  See AllTabards.txt for descriptions.
--
-- It it not recommended to add tabards into these categories as 
--	doing so may cause tabard selections to be incorrect in 'auto' 
--	mode.  Instead, create a custom tabard category in custom.lua
--	and select from that category instead.
--
-- To create alternate tabard categories in custom.lua
-- see http://wow.curseforge.com/addons/tabardmaster/forum/
--
----------------------------------------------------------------------

tm_tabardGroup = {
	-- the guild tabards spring collection, ordered by experience bonus ...
	['guild'] = 	'69210 69209 5976', -- "Renowned Guild Tabard" (epic), "Illustrious Guild Tabard" (rare), "Guild Tabard" (Normal)
	-- champion a city - all the city tabards
	['cities'] = '45574 45577 45578 45579 45580 45581 45582 45583 45584 45585 64882 64884 83079 83080',	
	-- pvp tabards
	['arena'] = '15196 15197 15198 15199 19031 19032 19160 19505 19506 20131 20132 36941 43349 45983 49052 49054 49086 51534 63378 63379 98162 101696 101697 103636 115972 127365 127366 127369 127371',
	-- everything else ...
	['misc'] = '22999 23192 23705 23709 24344 25549 28788 31279 38309 38310 38311 38312 38313 38314 31404 31405 35279 35280 40643 43300 43348 46817 46818 46874 52252 86468 89196 104008',
	-- these are dungeon tabards
	['D70tabards'] = '23999 24004 31773 31774 31775 31776 31777 31778 31779 31780 31781 31804 32445 32828 35221', -- Burning Crusades
	['D80tabards'] = '43154 43155 43156 43157',	-- Lich King
	['D85tabards'] = '65904 65905 65906 65907 65908 65909',	-- Cataclysm
	['D90tabards'] = '89401 89784 89795 89796 89797 89798 89799 89800 95591 95592 97131',	-- Pandaria
	-- Draenor; slave tabard, Wrynn's Vanguard, Vol'jin's Spear, Stormwind, Orgrimmar, Frostwolf Tabard, Council of Exarchs, Arakkoa Outcasts, Steamwheedle "Preservation" Society, Laughing Skull Orcs, Sha'tari Defense, Saberstalkers Tabard, Order of the Awakened Tabard
	['D100tabards'] = '107897 115517 115518 118365 118372 119133 119135 119136 119137 119138 119140 128449, 128450',
	-- Legion factions; Court of Farondis, Dreamweavers, Highmountain Tribe, The Nightfallen, The Wardens, Valarjar
	['D110tabards'] = '',
}


----------------------------------------------------------------------
--
-- tm_maps - TabardMaster's mapId mapping table
--
-- These are the mapIds of all zones, grouped into territories
-- 
-- See http://www.wowpedia.org/MapID for zone Ids
-- Alternatively, run this macro:
-- /run for mapId = 0, 1500 do i = GetMapNameByID(mapId);if i then print(mapId, "is zone", i);end;end
--
-- All we really need to keep track of, are PvE zones, world PvP zones, 
--	cities, and champion dungeons by level.  The addon can determine 
--	scenario, raid, pve and pvp zones on it's own through GetInstanceInfo() 
--	calls into the API.  Note that a "new" dungeon would be an unlisted 
--	zone with an instanceType of 'party', and a "new" raid would be just 
--	another 'raid' instanceType; raids are not separated by level, and 
--	scenarios are treated as dungeons.  This method, however,  allows for 
--	greater customization and finer control over which tabards and gearsets 
--	to wear for a given zone.
----------------------------------------------------------------------

-- Culled from multiple sources, including http://wow.gamepedia.com/MapID

tm_maps = {
-- See mapId.txt for conversion of mapId to zone name
	--Stormwind City, Ironforge, Darnassus, The Exodar, Shrine of Seven Stars, Stormshield
	['allianceCities'] = '301 341 381 471 905 1009',
	--Orgrimmar, Thunder Bluff, Undercity, Silvermoon City, Shrine of Two Moons, Warspear
	['hordeCities'] = '321 362 382 480 903 1011',
	-- NOTE: subzones 903 & 905 (the 2 Pandarian Shrines) do not generate a zone change event and use map 811 for now.
	-- neutral cities Shattrath City, Dalaran, lower Dalaran, Legion Dalaran.
	['neutralCities'] = '481 504 924 1014',
	--['arenas'] = 'ALL arenas Id as -1, (generic world) so are represented internally as mapId 9000'
	-- Wintergrasp, Tol Barad, Ashran
	['PvP Zone'] = '501 708 978',
	-- Battlegrounds (lvl 10) Arathi Basin, Warsong Gulch, (lvl 35) Eye of the Storm (482 & 813), (lvl 45) Alterac Valley, (lvl 65) Strand of the Ancients,
	--		(lvl 71) Isle of Conquest, (lvl 85) The Battle for Gilneas, Twin Peaks, (lvl 90) Temple of Kotmogu (856 & 881), Silvershard Mines, Deepwind Gorge
	['Battlegrounds'] = '461 443 482 813 401 512 540 736 626 856 881 860 935',

	--Kamimdor PvE territories
	['Kalimdor'] = '4 9 11 13 41 42 43 61 81 101 121 141 161 181 182 201 241 261 281 464 476 539 606 607 677 678 679 720 772 795 851 888 889 890 891 894',
	--Eastern Kingdoms PvE territories
	['Eastern Kingdoms'] = '14 16 17 19 20 21 22 23 24 26 27 28 29 30 32 34 35 36 37 38 39 40 462 463 499 502 545 610 611 613 614 615 673 684 685 689 700 709 770 864 866 892 893 895',
	-- Classic raids; Molten Core, Ruins of Ahn'Qiraj, Blackwing Lair, Temple of Ahn'Qiraj
	['Classic Raids'] = '696 717 755 766',
	-- Classic dungeons; these champion no factions.  Blackfathom Deeps, Blackrock Depths, Blackrock Spire, Dire Maul, 
	--		Gnomeregan, Maraudon, Ragefire Chasm, Razorfen Downs, Razorfen Kraul, Stratholme, The Stockade, 
	--		The Temple of Atal'Hakkar, Uldaman, Wailing Caverns, Zul'Farrak,  Scarlet Monastery, 
	--		Scholomance(Old), Stratholme, Deeprun Tram 922 & Brawl'gar Arena 925.  Deadmines and Shadowfang Keep are listed under X85;
	-- 		Scarlet Halls, Scarlet Monastery, & Scholomance are listed under X90.
	['D60'] = '680 686 687 688 690 691 692 699 704 721 749 750 760 761 762 763 765 922 925',
	-- Classic dungeons requiring heroic mode to champion.  None.
	--['H60'] = '',

	--Outland PvE territories
	['Outland'] = '465 466 467 473 475 477 478 479',
	-- Outland raids; Hyjal Summit, Gruul's Lair, Magtheridon's Lair, Serpentshrine Cavern, The Eye, Sunwell Plateau, Black Temple, Karazhan	
	['Outland Raids'] = '775 776 779 780 782 789 796 799',
	-- Outland dungeons; The Shattered Halls, Auchenai Crypts, Sethekk Halls, 
	--		Shadow Labyrinth, The Blood Furnace, The Underbog, The Steamvault, The Slave Pens, The Botanica, 
	--		The Mechanar, The Arcatraz, Mana-Tombs, The Black Morass, Old Hillsbrad Foothills, Hellfire Ramparts, 
	--		Magisters' Terrace			
	['D70'] = '710 722 723 724 725 726 727 728 729 730 731 732 733 734 797 798',
	-- Outland dungeons requiring heroic mode to champion.  None.
	--['H70'] = '',
	
	--Northrend PvE territories
	['Northrend'] = '485 486 488 490 491 492 493 495 496 510 541',
	-- Northrend raids; The Eye of Eternity, Ulduar, The Obsidian Sanctum, Vault of Archavon, Naxxramas, Trial of the Crusader, 
	--		Icecrown Citadel, The Ruby Sanctum, Onyxia's Lair
	['Northrend Raids'] = '527 529 531 532 535 543 604 609 718',
	-- Northrend dungeons that can be championed in any mode; Utgarde Pinnacle, The Culling of Stratholme, The Oculus, 
	--		Halls of Lightning, The Forge of Souls, Pit of Saron, & Halls of Reflection
	['D80'] = '521 524 525 528 601 602 603',
	-- Northrend dungeons requiring heroic mode to champion; The Nexus, Ahn'kahet: The Old Kingdom, Utgarde Keep, 
	--		Halls of Stone, Gundrak, Azjol-Nerub, Drak'Tharon Keep, The Violet Hold, Trial of the Champion, & The Nexus
	['H80'] = '520 522 523 526 530 533 534 536 542 803',

	-- Cataclysm PvE territories (including Darkmoon Island)
	['Cataclysm'] = '544 605 640 683 737 748 751 823',
	--	Cataclysm raids: Baradin Hold, Blackwing Descent, The Bastion of Twilight, Throne of the Four Winds, Firelands, Dragon Soul
	['Cataclysm Raids'] = '752 754 758 773 800 824',
	-- Cataclysm dungeons that can be championed in any mode; Grim Batol, Halls of Origination
	['D85'] = '757 759',
	-- Cataclysm dungeons requiring heroic mode to champion; Zul'Gurub, Lost City of the Tol'vir, Blackrock Caverns, 
	--		Throne of the Tides, The Stonecore, The Vortex Pinnacle, Zul'Aman, Zul'Gurub, Well of Eternity, 
	--		Hour of Twilight, & End Time
	['H85'] = '697 747 753 767 768 769 781 793 816 819 820',
	-- special treatment instances: Deadmines & Shadowfang Keep are D60 in normal mode, D85 in heroic.
	['X85'] = '756 764',

	-- Pandaria PvE territories
	['Pandaria'] = '806 807 808 809 810 811 857 858 862 873 681 682 928 951 955 928 929 933',	
	-- Pandarian raids: Terrace of Endless Spring, Mogu'shan Vaults, Heart of Fear, Throne of Thunder, Siege of Orgrimmar
	['Pandaria Raids'] = '886 896 897 930 953',
	-- Scenarios; are treated as D90 in mapDecoder()
	-- Vale of Eternal Blossoms (Dark Heart of Pandaria), The Secrets of Ragefire, Dun Morogh (Blood in the Snow), Battle on the High Seas
--	['Pandaria Scenarios'] = '878 879 880 882 883 884 899 900 906 907 910 911 912 914 919 920 934 937 938 939 940',
	-- Pandaria dungeons that can be championed in any mode; Gate of the Setting Sun & Siege of Niuzao Temple
	['D90'] = '875 887',
	-- Pandaria dungeons requiring heroic mode to champion;
	--		Temple of the Jade Serpent, Stormstout Brewery, Shado-Pan Monastery, & Mogu'shan Palace
	['H90'] = '867 876 877 885',
	 -- Scarlet Halls, Scarlet Monastery, & Scholomance are D60 normal, D90 heroic
	['X90'] = '871 874 898',

	-- Warlords of Draenor PvE territories
	['Draenor'] = '941 945 946 947 948 949 950 962 970 971 973 974 975 976 980 981 982 986 990 991 992 1011',
	-- Warlords of Draenor raids; Highmaul, Blackrock Foundry, Hellfire Citadel
	['Draenor Raids'] = '994 988 1026',
	-- Warlords of Draenor scenarios
--	['Draenor Scenarios'] = '983',
	-- Warlords of Draenor dungeons (that can be championed in any mode)
	--	Bloodmaul Slag Mines, Shadowmoon Burial Grounds, Auchindoun, Iron Docks, 
	--	Skyreach, Grimrail Depot, Upper Blackrock Spire, The Everbloom
	['D100'] = '964 969 984 987 989 993 995 1008',
	-- Warlords of Draenor dungeons requiring heroic mode to champion
	['H100'] = '',
	-- Warlords of Draenor mixed level dungeons
	['X100'] = '',

	-- Legion PvE territories
	-- Broken Isles, Aszuna, Stormheim, Val'sharah, Broken Shore, Highmountain, Suramar, Eye of Azshara
	['Legion'] = '1007 1015 1017 1018 1021 1024 1033 1098',
	-- Legion raids; 
	-- The Emerald Nightmare,  The Nighthold
	['Legion Raids'] = '1094 10828',
	-- Legion scenarios
--	['Legion Scenarios'] = '1079 1102 1027 1084',
	-- Legion dungeons (that can be championed in any mode)
	-- Halls of Valor, Maw of Souls, Vault of the Wardens, Eye of Azshara, Neltharion's Lair, 
	-- Violet Hold, Darkheart Thicket, The Arcway, Black Rook Hold, Court of Stars
	['D110'] = '1041 1042 1045 1046 1065 1066 1067 1079 1081 1087',
	-- Legion dungeons requiring heroic mode to champion
	['H110'] = '',
	-- Legion mixed level dungeons
	['X110'] = '',

	
----------------------------------------------------------------------
--
-- Mapping notes:
--
-- Warlords Garrison mapIDs from GetInstanceInfo()
--	[1152] = FW Horde Garrison Level 1
--	[1330] = FW Horde Garrison Level 2
--	[1153] = FW Horde Garrison Level 3
--	[1154] = FW Horde Garrison Level 4
--	[1158] = SMV Alliance Garrison Level 1
--	[1331] = SMV Alliance Garrison Level 2
--	[1159] = SMV Alliance Garrison Level 3
--	[1160] = SMV Alliance Garrison Level 4
--
--  [1116] = Draenor; all shipyards? 
--
-- These may end up in a tm_maps['garrison'] field later.  Shipyards 
--	do not generate zone change events and do not have their own mapIDs
--	though, so probably will not as the two should be treated the same.
--
-- Legion's Order Halls
--	map		zone							class			instanceID
-- -------------------------------------------------------------------
-- 1052 	Mardum, the Shattered Abyss 	Demon Hunter
-- 1077 	The Dreamgrove 					Druid
-- 1072 	Trueshot Lodge 					Hunter
-- 1068 	Hall of the Guardian 			Mage
-- 1044 	The Wandering Isle 				Monk
-- 1040 	Netherlight Temple 				Priest
-- 1057 	The Heart of Azeroth 			Shaman
-- 1035 	Skyhold 						Warrior			1479
--		 									Death Knight
--											Paladin
--											Rogue			1220
-- 1050		Dreadscar Rift					Warlock
--
----------------------------------------------------------------------
}
